@@ -62,7 +62,7 @@ MAPPING = {
 class SchedulerManager(manager.Manager):
     """Chooses a host to create shares."""
 
-    RPC_API_VERSION = '1.8'
+    RPC_API_VERSION = '1.9'
 
     def __init__(self, scheduler_driver=None, service_name=None,
                  *args, **kwargs):
@@ -81,9 +81,9 @@ class SchedulerManager(manager.Manager):
 
         self.driver = importutils.import_object(scheduler_driver)
         self.message_api = message_api.API()
-        super(self.__class__, self).__init__(*args, **kwargs)
+        super(SchedulerManager, self).__init__(*args, **kwargs)
 
-    def init_host(self):
+    def init_host_with_rpc(self):
         ctxt = context.get_admin_context()
         self.request_service_capabilities(ctxt)
 
@@ -120,21 +120,22 @@ class SchedulerManager(manager.Manager):
                     'create_share', {'status': constants.STATUS_ERROR},
                     context, ex, request_spec)
 
-    def get_pools(self, context, filters=None):
+    def get_pools(self, context, filters=None, cached=False):
         """Get active pools from the scheduler's cache."""
-        return self.driver.get_pools(context, filters)
+        return self.driver.get_pools(context, filters, cached)
 
     def manage_share(self, context, share_id, driver_options, request_spec,
                      filter_properties=None):
         """Ensure that the host exists and can accept the share."""
 
         def _manage_share_set_error(self, context, ex, request_spec):
-            # NOTE(nidhimittalhada): set size as 1 because design expects size
-            # to be set, it also will allow us to handle delete/unmanage
-            # operations properly with this errored share according to quotas.
+            # NOTE(haixin) if failed to scheduler backend for manage share,
+            # and we do not commit quota usages here, so we should set size 0
+            # because we don't know the real size of the size, and we will
+            # skip quota cuts when unmanage share with manage_error status.
             self._set_share_state_and_notify(
                 'manage_share',
-                {'status': constants.STATUS_MANAGE_ERROR, 'size': 1},
+                {'status': constants.STATUS_MANAGE_ERROR, 'size': 0},
                 context, ex, request_spec)
 
         share_ref = db.share_get(context, share_id)
