@@ -17,14 +17,10 @@
 Tests For Scheduler Manager
 """
 
-try:
-    # Python3 variant
-    from importlib import reload
-except ImportError:
-    pass
+from importlib import reload
+from unittest import mock
 
 import ddt
-import mock
 from oslo_config import cfg
 
 from manila.common import constants
@@ -48,7 +44,6 @@ CONF = cfg.CONF
 class SchedulerManagerTestCase(test.TestCase):
     """Test case for scheduler manager."""
 
-    manager_cls = manager.SchedulerManager
     driver_cls = base.Scheduler
     driver_cls_name = 'manila.scheduler.drivers.base.Scheduler'
 
@@ -68,14 +63,14 @@ class SchedulerManagerTestCase(test.TestCase):
         reload(manager)
 
         self.flags(scheduler_driver=self.driver_cls_name)
-        self.manager = self.manager_cls()
+        self.manager = manager.SchedulerManager()
         self.context = context.RequestContext('fake_user', 'fake_project')
         self.topic = 'fake_topic'
         self.fake_args = (1, 2, 3)
         self.fake_kwargs = {'cat': 'meow', 'dog': 'woof'}
 
-    def raise_no_valid_host(*args, **kwargs):
-            raise exception.NoValidHost(reason="")
+    def raise_no_valid_host(self, *args, **kwargs):
+        raise exception.NoValidHost(reason="")
 
     def test_1_correct_init(self):
         # Correct scheduler driver
@@ -90,14 +85,14 @@ class SchedulerManagerTestCase(test.TestCase):
 
         self.assertIsInstance(test_manager.driver, filter.FilterScheduler)
 
-    def test_init_host(self):
+    def test_init_host_with_rpc(self):
 
         self.mock_object(context,
                          'get_admin_context',
                          mock.Mock(return_value='fake_admin_context'))
         self.mock_object(self.manager, 'request_service_capabilities')
 
-        self.manager.init_host()
+        self.manager.init_host_with_rpc()
 
         self.manager.request_service_capabilities.assert_called_once_with(
             'fake_admin_context')
@@ -225,7 +220,8 @@ class SchedulerManagerTestCase(test.TestCase):
 
         result = self.manager.get_pools(self.context, filters='fake_filters')
 
-        mock_get_pools.assert_called_once_with(self.context, 'fake_filters')
+        mock_get_pools.assert_called_once_with(self.context, 'fake_filters',
+                                               False)
         self.assertEqual('fake_pools', result)
 
     @mock.patch.object(db, 'share_group_update', mock.Mock())
@@ -357,7 +353,7 @@ class SchedulerManagerTestCase(test.TestCase):
             {'share_id': share_id}, None)
         db_update.assert_called_once_with(
             self.context, share_id,
-            {'status': constants.STATUS_MANAGE_ERROR, 'size': 1})
+            {'status': constants.STATUS_MANAGE_ERROR, 'size': 0})
 
     def test_create_share_replica_exception_path(self):
         """Test 'raisable' exceptions for create_share_replica."""
